# Configuration script for Elizabeth Chak's Firefox Performance Testing project
# Seneca College, Toronto Canada.  2006.
# Authored by Dean William Woodside.  Email: dwwoodsi@learn.senecac.on.ca
# This work is public domain.  Use at your own peril.
# This script anticipates that you have visual studio installed.
#
#!/bin/bash
#
echo "Configuration script for Python Firefox Performance Testing project started...";
echo "Using $PWD/prereqs as a staging area.";
mkdir prereqs;
cd prereqs;
SFMIRRORS=(heanet jaist ovh switch mesh belnet umn superb-west surfnet nchc superb-east optusnet kent puzzle easynews ufpr);
MIRROR=${SFMIRRORS[$(($RANDOM%16))]};
MIRRORURL=http://${MIRROR}.dl.sourceforge.net/sourceforge;

# wget --spider to check that a mirror is available

echo "Downloading prerequisites from SourceForge mirror: ${MIRROR}";
# what about -U agent-string ? "Mozilla"
wget -nv -t 3 --waitretry=120 "http://www.python.org/ftp/python/2.4/python-2.4.msi";
wget -nv -t 3 --waitretry=120 "${MIRRORURL}/pywin32/pywin32-208.win32-py2.4.exe";
wget -nv -t 3 --waitretry=120 "${MIRRORURL}/numpy/Numeric-24.2.win32-py2.4.exe";
wget -nv -t 3 --waitretry=120 "${MIRRORURL}/matplotlib/matplotlib-0.87.3.win32-py2.4.exe";
wget -nv -t 3 --waitretry=120 "http://pyyaml.org/download/pysyck/PySyck-0.61.2.win32-py2.4.exe";
chmod u+x *;

echo "Files downloaded.  Now installing.";
msiexec /quiet /i python-2.4.msi;
# this is where perl-libwin32 would come in handy...
./pywin32-208.win32-py2.4.exe;
./Numeric-24.2.win32-py2.4.exe;
./matplotlib-0.87.3.win32-py2.4.exe;
./PySyck-0.61.2.win32-py2.4.exe;

echo "Downloading the Performance Testing Framework [yorku.ca]";
mkdir /cygdrive/c/mozilla;
cd /cygdrive/c/mozilla;
wget -nv -t 3 --waitretry=120 "http://www.yorku.ca/abel/liz/mozilla/Win32PerfTesting_v4.zip";
unzip -q Win32PerfTesting_v4.zip;
cd /cygdrive/c/mozilla/testing/performance/win32;

# set permissions (otherwise access is denied)
chmod u+rwx *;

echo "Creating config info file.";
echo "
      # Filename will be appended to the timestamp in the report filename.
      # Use letters and underscores only
      filename: ${1}
      # The title of the report
      title: ${2}
      
      # Name of profile to test
      Test profile 1:
        # Path to Firefox to test
        firefox: C:\Program Files\Mozilla Firefox\firefox.exe
        
        # Preferences to set in the test (use "preferences : {}" for no prefs)
        preferences:
          javascript.options.showInConsole : true
          xpinstall.enabled : true

        # Extensions to install in test (use "extensions: {}" for none)
        extensions: {}
          # Make sure that the path is directed to the desired location of the extension
          # Need quotes around guid because of curly braces" > config.yaml;

echo "Running the performance tests.";
./run_tests.py config.yaml;
